//
//  SkinCache.h
//  CheckboxAndRadio
//
//  Created by James Walker on 1/3/14.
//  Copyright (c) 2014 James W. Walker.

// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from
// the use of this software.

// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:

// 1. The origin of this software must not be misrepresented; you must not
// claim that you wrote the original software. If you use this software in a
// product, an acknowledgment in the product documentation would be
// appreciated but is not required.

// 2. Altered source versions must be plainly marked as such, and must not be
// misrepresented as being the original software.

// 3. This notice may not be removed or altered from any source distribution.
//

#import <Foundation/Foundation.h>

typedef enum SkinHighlight
{
	kSkinHighlight_None,
	kSkinHighlight_Pressed,
	kSkinHighlight_MouseOver
} SkinHighlight;

@interface SkinCache : NSObject

/*!
	@function	imageForKey:state:highlight:
	
	@abstract	Get a cached image for a button in a particular state.
	
	@discussion	The name state, and highlight values you provide are looked up
				in UISkin.plist, giving a resource name which is in turn
				fetched using -[NSImage imageNamed:].
				
				The SkinCache retains the image, so you do not need to retain
				or release it.
				
				If no image is found for the given highlight state, the cache
				will try again using kSkinHighlight_None as a fallback value.

	@param		name		Name of a set of image resource names in
							UISkin.plist.
	@param		buttonState	State of the button being drawn.
	@param		hilite		Desired highlight state, from SkinHighlight.
	@result		An image, or nil if it is not found.
*/
+ (NSImage*) imageForKey: (NSString*) name
			state: (NSInteger) buttonState
			highlight: (SkinHighlight) hilite;

@end
