//
//  SkinCheckboxCell.m
//  CheckboxAndRadio
//
//  Created by James Walker on 1/3/14.
//  Copyright (c) 2014 James W. Walker.

// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from
// the use of this software.

// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:

// 1. The origin of this software must not be misrepresented; you must not
// claim that you wrote the original software. If you use this software in a
// product, an acknowledgment in the product documentation would be
// appreciated but is not required.

// 2. Altered source versions must be plainly marked as such, and must not be
// misrepresented as being the original software.

// 3. This notice may not be removed or altered from any source distribution.
//

#import "SkinCheckboxCell.h"

#import "SkinCache.h"

@implementation SkinCheckboxCell

@synthesize images = mImages;

- (id) initWithCoder:(NSCoder *)aDecoder
{
	self = [super initWithCoder: aDecoder];
	
	if (self != nil)
	{
		mIsMouseOver = NO;
	}
	
	return self;
}

- (void) dealloc
{
	[mImages release];
	
	[super dealloc];
}

// Implementing copyWithZone: is essential for use in a table.
- (id)copyWithZone:(NSZone *)zone
{
	SkinCheckboxCell* theCopy = [super copyWithZone: zone];
	
	theCopy->mIsMouseOver = NO;

	theCopy->mImages = [mImages retain];
	
	return theCopy;
}

- (void)drawImage:(NSImage *)image
		withFrame:(NSRect)frame
		inView:(NSView *)controlView
{
	SkinHighlight hiliteState = kSkinHighlight_None;
	if ([self isHighlighted])
	{
		hiliteState = kSkinHighlight_Pressed;
	}
	else if (mIsMouseOver)
	{
		hiliteState = kSkinHighlight_MouseOver;
	}
	
	NSImage* theImage = [SkinCache imageForKey: self.images
									state: [self state]
									highlight: hiliteState ];

	float alpha = [self isEnabled]? 1.0f : 0.25f;
	
	if ([theImage isKindOfClass: [NSImage class]])
	{
		[theImage drawInRect: frame
					fromRect: NSZeroRect
					operation: NSCompositeSourceOver
					fraction: alpha
					respectFlipped: YES
					hints: NULL];
	}
}

- (BOOL)showsBorderOnlyWhileMouseInside
{
	// Making this return YES gives us mouseEntered: and mouseExited: messages.
	return YES;
}

- (void)mouseEntered:(NSEvent *)event
{
	mIsMouseOver = [self isEnabled];
	[[self controlView] setNeedsDisplay: YES];
}

- (void)mouseExited:(NSEvent *)event
{
	mIsMouseOver = NO;
	[[self controlView] setNeedsDisplay: YES];
}


@end
